slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPMonitorRegister

Adds PEP monitor routine.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPMonitorRegister(const char name[],PetscViewerType vtype,PetscViewerFormat format,PetscErrorCode (*monitor)(PEP,PetscInt,PetscInt,PetscScalar*,PetscScalar*,PetscReal*,PetscInt,PetscViewerAndFormat*),PetscErrorCode (*create)(PetscViewer,PetscViewerFormat,void*,PetscViewerAndFormat**),PetscErrorCode (*destroy)(PetscViewerAndFormat**))

Not Collective

### Input Parameters

| name | - name of a new monitor routine
| vtype | - a PetscViewerType for the output
| format | - a PetscViewerFormat for the output
| monitor | - monitor routine
| create | - creation routine, or NULL
| destroy | - destruction routine, or NULL

### Notes

PEPMonitorRegister() may be called multiple times to add several user-defined monitors.

### Sample usage

       PEPMonitorRegister("my_monitor",PETSCVIEWERASCII,PETSC_VIEWER_ASCII_INFO_DETAIL,MyMonitor,NULL,NULL);

Then, your monitor can be chosen with the procedural interface via

         PEPMonitorSetFromOptions(pep,"-pep_monitor_my_monitor","my_monitor",NULL)

or at runtime via the option

         -pep_monitor_my_monitor

### See Also

PEPMonitorRegisterAll()

### Level

advanced

### Location

src/pep/interface/pepbasic.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages